==> vlc-remote_0.5-1.tar.gz: vlc-remote-0.5/src/accountdialog.h <==
/*   VLC-REMOTE for MAEMO 5
*   Copyright (C) 2010 Schutz Sacha <istdasklar@gmail.com>, Dru Moore <usr@dru-id.co.uk>, Yann Nave <yannux@onbebop.net>
*   This program is free software; you can redistribute it and/or modify
*   it under the terms of the GNU General Public License version 2,
*   or (at your option) any later version, as published by the Free
*   Software Foundation
*
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details
*
*   You should have received a copy of the GNU General Public
*   License along with this program; if not, write to the
*   Free Software Foundation, Inc.,
*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
#ifndef ACCOUNTDIALOG_H
#define ACCOUNTDIALOG_H

#include <QDialog>
#include <QListWidget>
#include <QFutureWatcher>
namespace Ui {
    class AccountDialog;
}

class AccountDialog : public QDialog
{
    Q_OBJECT

public:
    explicit AccountDialog(QWidget *parent = 0);
    ~AccountDialog();
     static QListWidgetItem asyncTestItem(const QListWidgetItem& item);


static QString  currentIp();

public slots:
    void add();
    void edit();
    void rem();
    void use();
    void load();
    void enableUi();
 void setAsyncItem(int row);
private:
    Ui::AccountDialog *ui;
    QFutureWatcher <QListWidgetItem> * mFuturWatcher;
};

#endif // ACCOUNTDIALOG_H

==> vlc-remote_0.6-1.tar.gz: vlc-remote-0.6/src/accountdialog.h <==
/*   VLC-REMOTE for MAEMO 5
*   Copyright (C) 2010 Schutz Sacha <istdasklar@gmail.com>, Dru Moore <usr@dru-id.co.uk>, Yann Nave <yannux@onbebop.net>
*   This program is free software; you can redistribute it and/or modify
*   it under the terms of the GNU General Public License version 2,
*   or (at your option) any later version, as published by the Free
*   Software Foundation
*
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details
*
*   You should have received a copy of the GNU General Public
*   License along with this program; if not, write to the
*   Free Software Foundation, Inc.,
*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
#ifndef ACCOUNTDIALOG_H
#define ACCOUNTDIALOG_H

#include <QDialog>
#include <QListWidget>
#include <QFutureWatcher>
namespace Ui {
    class AccountDialog;
}

class AccountDialog : public QDialog
{
    Q_OBJECT

public:
    explicit AccountDialog(QWidget *parent = 0);
    ~AccountDialog();
     static QListWidgetItem asyncTestItem(const QListWidgetItem& item);


//static QString  currentIp();

public slots:
    void add();
    void edit();
    void rem();
    void use();
    void load();
    void enableUi();
 void setAsyncItem(int row);
private:
    Ui::AccountDialog *ui;
    QFutureWatcher <QListWidgetItem> * mFuturWatcher;
};

#endif // ACCOUNTDIALOG_H
